pub struct TransformData {
pub position: Vec3,
pub rotation: Quat,
pub scale: Vec3,
}Fields
position: Vec3rotation: Quatscale: Vec3Trait Implementations
Sourceimpl Clone for TransformData
impl Clone for TransformData
Sourcefn clone(&self) -> TransformData
fn clone(&self) -> TransformData
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransformData
impl Debug for TransformData
Sourceimpl<'de> Deserialize<'de> for TransformData
impl<'de> Deserialize<'de> for TransformData
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<TransformData, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TransformData, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<TransformData> for Transform
impl From<TransformData> for Transform
Sourcefn from(data: TransformData) -> Transform
fn from(data: TransformData) -> Transform
Converts to this type from the input type.
Sourceimpl FromArg for &'static TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl FromArg for &'static TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Sourceimpl FromArg for &'static mut TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl FromArg for &'static mut TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Sourceimpl FromArg for TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl FromArg for TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Sourceimpl FromReflect for TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl FromReflect for TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Sourcefn from_reflect(
reflect: &(dyn PartialReflect + 'static),
) -> Option<TransformData>
fn from_reflect( reflect: &(dyn PartialReflect + 'static), ) -> Option<TransformData>
Constructs a concrete instance of
Self from a reflected value.Sourcefn take_from_reflect(
reflect: Box<dyn PartialReflect>,
) -> Result<Self, Box<dyn PartialReflect>>
fn take_from_reflect( reflect: Box<dyn PartialReflect>, ) -> Result<Self, Box<dyn PartialReflect>>
Attempts to downcast the given value to
Self using,
constructing the value using from_reflect if that fails. Read moreSourceimpl GetOwnership for &TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl GetOwnership for &TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Sourceimpl GetOwnership for &mut TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl GetOwnership for &mut TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Sourceimpl GetOwnership for TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl GetOwnership for TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Sourceimpl GetTypeRegistration for TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl GetTypeRegistration for TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Sourcefn get_type_registration() -> TypeRegistration
fn get_type_registration() -> TypeRegistration
Returns the default
TypeRegistration for this type.Sourcefn register_type_dependencies(registry: &mut TypeRegistry)
fn register_type_dependencies(registry: &mut TypeRegistry)
Registers other types needed by this type. Read more
Sourceimpl IntoReturn for &TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl IntoReturn for &TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
&TransformData: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
&TransformData: 'into_return,
Sourceimpl IntoReturn for &mut TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl IntoReturn for &mut TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
&mut TransformData: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
&mut TransformData: 'into_return,
Sourceimpl IntoReturn for TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl IntoReturn for TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Sourcefn into_return<'into_return>(self) -> Return<'into_return>where
TransformData: 'into_return,
fn into_return<'into_return>(self) -> Return<'into_return>where
TransformData: 'into_return,
Sourceimpl PartialEq for TransformData
impl PartialEq for TransformData
Sourcefn eq(&self, other: &TransformData) -> bool
fn eq(&self, other: &TransformData) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialReflect for TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl PartialReflect for TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Sourcefn get_represented_type_info(&self) -> Option<&'static TypeInfo>
fn get_represented_type_info(&self) -> Option<&'static TypeInfo>
Sourcefn clone_value(&self) -> Box<dyn PartialReflect>
fn clone_value(&self) -> Box<dyn PartialReflect>
Clones the value as a
Reflect trait object. Read moreSourcefn try_apply(
&mut self,
value: &(dyn PartialReflect + 'static),
) -> Result<(), ApplyError>
fn try_apply( &mut self, value: &(dyn PartialReflect + 'static), ) -> Result<(), ApplyError>
Sourcefn reflect_kind(&self) -> ReflectKind
fn reflect_kind(&self) -> ReflectKind
Returns a zero-sized enumeration of “kinds” of type. Read more
Sourcefn reflect_ref(&self) -> ReflectRef<'_>
fn reflect_ref(&self) -> ReflectRef<'_>
Returns an immutable enumeration of “kinds” of type. Read more
Sourcefn reflect_mut(&mut self) -> ReflectMut<'_>
fn reflect_mut(&mut self) -> ReflectMut<'_>
Returns a mutable enumeration of “kinds” of type. Read more
Sourcefn reflect_owned(self: Box<TransformData>) -> ReflectOwned
fn reflect_owned(self: Box<TransformData>) -> ReflectOwned
Returns an owned enumeration of “kinds” of type. Read more
Sourcefn try_into_reflect(
self: Box<TransformData>,
) -> Result<Box<dyn Reflect>, Box<dyn PartialReflect>>
fn try_into_reflect( self: Box<TransformData>, ) -> Result<Box<dyn Reflect>, Box<dyn PartialReflect>>
Attempts to cast this type to a boxed, fully-reflected value.
Sourcefn try_as_reflect(&self) -> Option<&(dyn Reflect + 'static)>
fn try_as_reflect(&self) -> Option<&(dyn Reflect + 'static)>
Attempts to cast this type to a fully-reflected value.
Sourcefn try_as_reflect_mut(&mut self) -> Option<&mut (dyn Reflect + 'static)>
fn try_as_reflect_mut(&mut self) -> Option<&mut (dyn Reflect + 'static)>
Attempts to cast this type to a mutable, fully-reflected value.
Sourcefn into_partial_reflect(self: Box<TransformData>) -> Box<dyn PartialReflect>
fn into_partial_reflect(self: Box<TransformData>) -> Box<dyn PartialReflect>
Casts this type to a boxed, reflected value. Read more
Sourcefn as_partial_reflect(&self) -> &(dyn PartialReflect + 'static)
fn as_partial_reflect(&self) -> &(dyn PartialReflect + 'static)
Casts this type to a reflected value. Read more
Sourcefn as_partial_reflect_mut(&mut self) -> &mut (dyn PartialReflect + 'static)
fn as_partial_reflect_mut(&mut self) -> &mut (dyn PartialReflect + 'static)
Casts this type to a mutable, reflected value. Read more
Sourcefn reflect_partial_eq(
&self,
value: &(dyn PartialReflect + 'static),
) -> Option<bool>
fn reflect_partial_eq( &self, value: &(dyn PartialReflect + 'static), ) -> Option<bool>
Returns a “partial equality” comparison result. Read more
Sourcefn apply(&mut self, value: &(dyn PartialReflect + 'static))
fn apply(&mut self, value: &(dyn PartialReflect + 'static))
Applies a reflected value to this value. Read more
Sourcefn reflect_hash(&self) -> Option<u64>
fn reflect_hash(&self) -> Option<u64>
Returns a hash of the value (which includes the type). Read more
Sourcefn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error>
fn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error>
Debug formatter for the value. Read more
Sourcefn serializable(&self) -> Option<Serializable<'_>>
fn serializable(&self) -> Option<Serializable<'_>>
Returns a serializable version of the value. Read more
Sourcefn is_dynamic(&self) -> bool
fn is_dynamic(&self) -> bool
Indicates whether or not this type is a dynamic type. Read more
Sourceimpl Reflect for TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl Reflect for TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Sourcefn into_any(self: Box<TransformData>) -> Box<dyn Any>
fn into_any(self: Box<TransformData>) -> Box<dyn Any>
Returns the value as a
Box<dyn Any>. Read moreSourcefn as_any_mut(&mut self) -> &mut (dyn Any + 'static)
fn as_any_mut(&mut self) -> &mut (dyn Any + 'static)
Returns the value as a
&mut dyn Any. Read moreSourcefn into_reflect(self: Box<TransformData>) -> Box<dyn Reflect>
fn into_reflect(self: Box<TransformData>) -> Box<dyn Reflect>
Casts this type to a boxed, fully-reflected value.
Sourcefn as_reflect(&self) -> &(dyn Reflect + 'static)
fn as_reflect(&self) -> &(dyn Reflect + 'static)
Casts this type to a fully-reflected value.
Sourcefn as_reflect_mut(&mut self) -> &mut (dyn Reflect + 'static)
fn as_reflect_mut(&mut self) -> &mut (dyn Reflect + 'static)
Casts this type to a mutable, fully-reflected value.
Sourceimpl Serialize for TransformData
impl Serialize for TransformData
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl Struct for TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl Struct for TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Sourcefn field(&self, name: &str) -> Option<&(dyn PartialReflect + 'static)>
fn field(&self, name: &str) -> Option<&(dyn PartialReflect + 'static)>
Returns a reference to the value of the field named
name as a &dyn PartialReflect.Sourcefn field_mut(
&mut self,
name: &str,
) -> Option<&mut (dyn PartialReflect + 'static)>
fn field_mut( &mut self, name: &str, ) -> Option<&mut (dyn PartialReflect + 'static)>
Returns a mutable reference to the value of the field named
name as a
&mut dyn PartialReflect.Sourcefn field_at(&self, index: usize) -> Option<&(dyn PartialReflect + 'static)>
fn field_at(&self, index: usize) -> Option<&(dyn PartialReflect + 'static)>
Returns a reference to the value of the field with index
index as a
&dyn PartialReflect.Sourcefn field_at_mut(
&mut self,
index: usize,
) -> Option<&mut (dyn PartialReflect + 'static)>
fn field_at_mut( &mut self, index: usize, ) -> Option<&mut (dyn PartialReflect + 'static)>
Returns a mutable reference to the value of the field with index
index
as a &mut dyn PartialReflect.Sourcefn name_at(&self, index: usize) -> Option<&str>
fn name_at(&self, index: usize) -> Option<&str>
Returns the name of the field with index
index.Sourcefn iter_fields(&self) -> FieldIter<'_>
fn iter_fields(&self) -> FieldIter<'_>
Returns an iterator over the values of the reflectable fields for this struct.
Sourcefn clone_dynamic(&self) -> DynamicStruct
fn clone_dynamic(&self) -> DynamicStruct
Clones the struct into a
DynamicStruct.Sourcefn get_represented_struct_info(&self) -> Option<&'static StructInfo>
fn get_represented_struct_info(&self) -> Option<&'static StructInfo>
Will return
None if TypeInfo is not available.Sourceimpl TypePath for TransformData
impl TypePath for TransformData
Sourcefn type_path() -> &'static str
fn type_path() -> &'static str
Returns the fully qualified path of the underlying type. Read more
Sourcefn short_type_path() -> &'static str
fn short_type_path() -> &'static str
Returns a short, pretty-print enabled path to the type. Read more
Sourcefn type_ident() -> Option<&'static str>
fn type_ident() -> Option<&'static str>
Sourcefn crate_name() -> Option<&'static str>
fn crate_name() -> Option<&'static str>
Sourceimpl Typed for TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl Typed for TransformDatawhere
TransformData: Any + Send + Sync,
Vec3: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
Quat: FromReflect + TypePath + MaybeTyped + RegisterForReflection,
impl Copy for TransformData
impl StructuralPartialEq for TransformData