pub struct PreFracturedCache {
pub cache: HashMap<Entity, Vec<ProceduralChunk>>,
}Expand description
Stores pre-fractured chunks to avoid expensive runtime calculations (Pre-fracture Caching). Ideal for AAA games where destruction must not drop frames.
Fields
cache: HashMap<Entity, Vec<ProceduralChunk>>Maps an Entity ID to its pre-calculated fracture data
Implementations
Sourceimpl PreFracturedCache
impl PreFracturedCache
pub fn new() -> PreFracturedCache
Sourcepub fn pre_fracture(
&mut self,
entity: Entity,
extents: Vec3,
num_pieces: u32,
seed: u64,
)
pub fn pre_fracture( &mut self, entity: Entity, extents: Vec3, num_pieces: u32, seed: u64, )
Pre-calculates fracture chunks for an entity and stores them in the cache. This should be called during a loading screen.
Sourcepub fn get_fracture_chunks(
&self,
entity: Entity,
original_transform: &Transform,
original_body: &RigidBody,
original_velocity: &Velocity,
impact_point: Vec3,
impact_force: f32,
) -> Option<Vec<(RigidBody, Transform, Collider, Velocity, ProceduralChunk)>>
pub fn get_fracture_chunks( &self, entity: Entity, original_transform: &Transform, original_body: &RigidBody, original_velocity: &Velocity, impact_point: Vec3, impact_force: f32, ) -> Option<Vec<(RigidBody, Transform, Collider, Velocity, ProceduralChunk)>>
Spawns the chunks from the cache if available, taking only O(N) time to clone instead of O(N^3). If not in cache, optionally falls back to runtime calculation.