pub enum AbstractAxis {
Inline,
Block,
}Expand description
The CSS abstract axis https://www.w3.org/TR/css-writing-modes-3/#abstract-axes
Variants
Inline
The axis in the inline dimension, i.e. the horizontal axis in horizontal writing modes and the vertical axis in vertical writing modes.
Block
The axis in the block dimension, i.e. the vertical axis in horizontal writing modes and the horizontal axis in vertical writing modes.
Implementations
Sourceimpl AbstractAxis
impl AbstractAxis
Sourcepub const fn other(&self) -> AbstractAxis
pub const fn other(&self) -> AbstractAxis
Returns the other variant of the enum
Sourcepub const fn as_abs_naive(&self) -> AbsoluteAxis
pub const fn as_abs_naive(&self) -> AbsoluteAxis
Convert an AbstractAxis into an AbsoluteAxis naively assuming that the Inline axis is Horizontal
This is currently always true, but will change if Taffy ever implements the writing_mode property