pub enum BoxGenerationMode {
Normal,
None,
}Expand description
An abstracted version of the CSS display property where any value other than “none” is represented by “normal”
See: https://www.w3.org/TR/css-display-3/#box-generation
Variants
Normal
The node generates a box in the regular way
None
The node and it’s descendants generate no boxes (they are hidden)
Implementations
Sourceimpl BoxGenerationMode
impl BoxGenerationMode
Sourcepub const DEFAULT: BoxGenerationMode = BoxGenerationMode::Normal
pub const DEFAULT: BoxGenerationMode = BoxGenerationMode::Normal
The default of BoxGenerationMode