pub enum GenericGridPlacement<LineType>where
LineType: GridCoordinate,{
Auto,
Line(LineType),
Span(u16),
}Expand description
A grid line placement specification which is generic over the coordinate system that it uses to define grid line positions.
GenericGridPlacement<GridLine> is aliased as GridPlacement and is exposed to users of Taffy to define styles.
GenericGridPlacement<OriginZeroLine> is aliased as OriginZeroGridPlacement and is used internally for placement computations.
Variants
Auto
Place item according to the auto-placement algorithm, and the parent’s grid_auto_flow property
Line(LineType)
Place item at specified line (column or row) index
Span(u16)
Item should span specified number of tracks (columns or rows)
Implementations
Sourceimpl GenericGridPlacement<GridLine>
impl GenericGridPlacement<GridLine>
Sourcepub fn into_origin_zero_placement(
&self,
explicit_track_count: u16,
) -> GenericGridPlacement<OriginZeroLine>
pub fn into_origin_zero_placement( &self, explicit_track_count: u16, ) -> GenericGridPlacement<OriginZeroLine>
Apply a mapping function if the GridPlacement is a Track. Otherwise return self unmodified.