pub enum GridPlacement<S = String>where
S: CheapCloneStr,{
Auto,
Line(GridLine),
NamedLine(S, i16),
Span(u16),
NamedSpan(S, u16),
}Expand description
A grid line placement specification. Used for grid-[row/column]-[start/end]. Named tracks are not implemented.
Defaults to GridPlacement::Auto
Variants
Auto
Place item according to the auto-placement algorithm, and the parent’s grid_auto_flow property
Line(GridLine)
Place item at specified line (column or row) index
NamedLine(S, i16)
Place item at specified named line (column or row)
Span(u16)
Item should span specified number of tracks (columns or rows)
NamedSpan(S, u16)
Item should span until the nth line named <name>.
If there are less than n lines named <name> in the specified direction then
all implicit lines will be counted.
Implementations
Sourceimpl<S> GridPlacement<S>where
S: CheapCloneStr,
impl<S> GridPlacement<S>where
S: CheapCloneStr,
Sourcepub fn into_origin_zero_placement_ignoring_named(
&self,
explicit_track_count: u16,
) -> GenericGridPlacement<OriginZeroLine>
pub fn into_origin_zero_placement_ignoring_named( &self, explicit_track_count: u16, ) -> GenericGridPlacement<OriginZeroLine>
Apply a mapping function if the GridPlacement is a Line. Otherwise return self unmodified.