pub enum GridTemplateComponent<S>where
S: CheapCloneStr,{
Single(MinMax<MinTrackSizingFunction, MaxTrackSizingFunction>),
Repeat(GridTemplateRepetition<S>),
}Expand description
An element in a grid-template-columns or grid-template-rows definition.
Either a track sizing function or a repeat().
See https://developer.mozilla.org/en-US/docs/Web/CSS/grid-template-columns
Variants
Single(MinMax<MinTrackSizingFunction, MaxTrackSizingFunction>)
A single non-repeated track
Repeat(GridTemplateRepetition<S>)
Automatically generate grid tracks to fit the available space using the specified definite track lengths Only valid if every track in template (not just the repetition) has a fixed size.
Implementations
Sourceimpl<S> GridTemplateComponent<S>where
S: CheapCloneStr,
impl<S> GridTemplateComponent<S>where
S: CheapCloneStr,
Sourcepub fn as_component_ref(
&self,
) -> GenericGridTemplateComponent<S, &GridTemplateRepetition<S>>
pub fn as_component_ref( &self, ) -> GenericGridTemplateComponent<S, &GridTemplateRepetition<S>>
Convert a GridTemplateComponent into a GridTemplateComponentRef
Sourceimpl<S> GridTemplateComponent<S>where
S: CheapCloneStr,
impl<S> GridTemplateComponent<S>where
S: CheapCloneStr,
Sourcepub fn is_auto_repetition(&self) -> bool
pub fn is_auto_repetition(&self) -> bool
Whether the track definition is a auto-repeated fragment