pub enum RepetitionCount {
AutoFill,
AutoFit,
Count(u16),
}Expand description
The first argument to a repeated track definition. This type represents the type of automatic repetition to perform.
See https://www.w3.org/TR/css-grid-1/#auto-repeat for an explanation of how auto-repeated track definitions work and the difference between AutoFit and AutoFill.
Variants
AutoFill
Auto-repeating tracks should be generated to fit the container See: https://developer.mozilla.org/en-US/docs/Web/CSS/repeat#auto-fill
AutoFit
Auto-repeating tracks should be generated to fit the container See: https://developer.mozilla.org/en-US/docs/Web/CSS/repeat#auto-fit
Count(u16)
The specified tracks should be repeated exacts N times