pub struct GridTemplateArea<CustomIdent>where
CustomIdent: CheapCloneStr,{
pub name: CustomIdent,
pub row_start: u16,
pub row_end: u16,
pub column_start: u16,
pub column_end: u16,
}Expand description
Defines a grid area
Fields
name: CustomIdentThe name of the grid area which
row_start: u16The index of the row at which the grid area starts in grid coordinates.
row_end: u16The index of the row at which the grid area ends in grid coordinates.
column_start: u16The index of the column at which the grid area starts in grid coordinates.
column_end: u16The index of the column at which the grid area end in grid coordinates.