BlockContainerStyle

Trait BlockContainerStyle 

pub trait BlockContainerStyle: CoreStyle {
    // Provided method
    fn text_align(&self) -> TextAlign { ... }
}
The set of styles required for a Block layout container

Provided Methods

fn text_align(&self) -> TextAlign

Defines which row in the grid the item should start and end at

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> BlockContainerStyle for &T

Available on crate feature block_layout only.

Implementors

Source

impl<S> BlockContainerStyle for Style<S>
where S: CheapCloneStr,

Available on crate feature block_layout only.