pub trait TemplateLineNames<'a, S>:
Iterator<Item = Self::LineNameSet<'a>>
+ ExactSizeIterator
+ Clone
+ 'awhere
S: CheapCloneStr,{
type LineNameSet<'b>: Iterator<Item = &'b S> + ExactSizeIterator + Clone
where Self: 'b;
}Expand description
A nested list of line names. This is effectively a generic representation of Vec<Vec<String>> that allows
both the collection and string type to be customised.
Required Associated Types
Sourcetype LineNameSet<'b>: Iterator<Item = &'b S> + ExactSizeIterator + Clone
where
Self: 'b
type LineNameSet<'b>: Iterator<Item = &'b S> + ExactSizeIterator + Clone where Self: 'b
A simple list line names. This is effectively a generic representation of VecString> that allows
both the collection and string type to be customised.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".