pub fn physics_step_system(world: &World, dt: f32)Expand description
Exclusive system that updates the entire physics simulation. It reads all rigid and soft bodies from the ECS, steps the physics world, and writes the transformed positions and velocities back to the ECS.