pub struct LengthPercentage(/* private fields */);Expand description
Implementations
Sourceimpl LengthPercentage
impl LengthPercentage
Sourcepub const fn length(val: f32) -> LengthPercentage
pub const fn length(val: f32) -> LengthPercentage
An absolute length in some abstract units. Users of Taffy may define what they correspond to in their application (pixels, logical pixels, mm, etc) as they see fit.
Sourcepub const fn percent(val: f32) -> LengthPercentage
pub const fn percent(val: f32) -> LengthPercentage
A percentage length relative to the size of the containing block.
NOTE: percentages are represented as a f32 value in the range [0.0, 1.0] NOT the range [0.0, 100.0]
Sourcepub fn calc(ptr: *const ()) -> LengthPercentage
pub fn calc(ptr: *const ()) -> LengthPercentage
A calc() value. The value passed here is treated as an opaque handle to
the actual calc representation and may be a pointer, index, etc.
The low 3 bits are used as a tag value and will be returned as 0.
Sourcepub const unsafe fn from_raw(val: CompactLength) -> LengthPercentage
pub const unsafe fn from_raw(val: CompactLength) -> LengthPercentage
Create a LengthPercentage from a raw CompactLength.
Safety
CompactLength must represent a valid variant for LengthPercentage
Sourcepub const fn into_raw(self) -> CompactLength
pub const fn into_raw(self) -> CompactLength
Get the underlying CompactLength representation of the value