pub struct Size<T> {
pub width: T,
pub height: T,
}Expand description
The width and height of a Rect
Fields
width: TThe x extent of the rectangle
height: TThe y extent of the rectangle
Implementations
Sourceimpl<T> Size<T>
impl<T> Size<T>
Sourcepub fn get_abs(self, axis: AbsoluteAxis) -> T
pub fn get_abs(self, axis: AbsoluteAxis) -> T
Get either the width or height depending on the AbsoluteAxis passed in
Sourceimpl<T> Size<T>
impl<T> Size<T>
Sourcepub fn map<R, F>(self, f: F) -> Size<R>where
F: Fn(T) -> R,
pub fn map<R, F>(self, f: F) -> Size<R>where
F: Fn(T) -> R,
Applies the function f to both the width and height
This is used to transform a Size<T> into a Size<R>.
Sourcepub fn map_width<F>(self, f: F) -> Size<T>where
F: Fn(T) -> T,
pub fn map_width<F>(self, f: F) -> Size<T>where
F: Fn(T) -> T,
Applies the function f to the width
Sourcepub fn map_height<F>(self, f: F) -> Size<T>where
F: Fn(T) -> T,
pub fn map_height<F>(self, f: F) -> Size<T>where
F: Fn(T) -> T,
Applies the function f to the height
Sourceimpl Size<f32>
impl Size<f32>
Sourcepub fn has_non_zero_area(self) -> bool
pub fn has_non_zero_area(self) -> bool
Return true if both width and height are greater than 0 else false
Sourceimpl Size<Option<f32>>
impl Size<Option<f32>>
Sourcepub const fn new(width: f32, height: f32) -> Size<Option<f32>>
pub const fn new(width: f32, height: f32) -> Size<Option<f32>>
A Size<Option<f32>> with Some(width) and Some(height) as parameters
Sourcepub const fn from_cross(
direction: FlexDirection,
value: Option<f32>,
) -> Size<Option<f32>>
pub const fn from_cross( direction: FlexDirection, value: Option<f32>, ) -> Size<Option<f32>>
Creates a new Size<Option<f32>> with either the width or height set based on the provided direction
Sourcepub fn maybe_apply_aspect_ratio(
self,
aspect_ratio: Option<f32>,
) -> Size<Option<f32>>
pub fn maybe_apply_aspect_ratio( self, aspect_ratio: Option<f32>, ) -> Size<Option<f32>>
Applies aspect_ratio (if one is supplied) to the Size:
- If width is
Somebut height isNone, then height is computed from width and aspect_ratio - If height is
Somebut width isNone, then width is computed from height and aspect_ratio
If aspect_ratio is None then this function simply returns self.
Sourceimpl<T> Size<Option<T>>
impl<T> Size<Option<T>>
Sourcepub fn unwrap_or(self, alt: Size<T>) -> Size<T>
pub fn unwrap_or(self, alt: Size<T>) -> Size<T>
Performs Option::unwrap_or on each component separately
Sourcepub fn or(self, alt: Size<Option<T>>) -> Size<Option<T>>
pub fn or(self, alt: Size<Option<T>>) -> Size<Option<T>>
Performs Option::or on each component separately
Sourcepub fn both_axis_defined(&self) -> bool
pub fn both_axis_defined(&self) -> bool
Return true if both components are Some, else false.
Sourceimpl Size<Dimension>
impl Size<Dimension>
Sourcepub const fn from_lengths(width: f32, height: f32) -> Size<Dimension>
pub const fn from_lengths(width: f32, height: f32) -> Size<Dimension>
Generates a Size<Dimension> using length values
Sourcepub const fn from_percent(width: f32, height: f32) -> Size<Dimension>
pub const fn from_percent(width: f32, height: f32) -> Size<Dimension>
Generates a Size<Dimension> using percentage values
Sourceimpl Size<AvailableSpace>
impl Size<AvailableSpace>
Sourceimpl<T> Size<T>where
T: TaffyMinContent,
impl<T> Size<T>where
T: TaffyMinContent,
Sourcepub const fn min_content() -> Size<T>
pub const fn min_content() -> Size<T>
Returns a Size where both the width and height values are the min_content value of the contained type (e.g. Dimension::Auto or LengthPercentageAuto::Auto)
Sourceimpl<T> Size<T>where
T: TaffyMaxContent,
impl<T> Size<T>where
T: TaffyMaxContent,
Sourcepub const fn max_content() -> Size<T>
pub const fn max_content() -> Size<T>
Returns a Size where both the width and height values are the max_content value of the contained type (e.g. Dimension::Auto or LengthPercentageAuto::Auto)
Sourceimpl<T> Size<T>where
T: TaffyFitContent,
impl<T> Size<T>where
T: TaffyFitContent,
Sourcepub fn fit_content(argument: LengthPercentage) -> Size<T>
pub fn fit_content(argument: LengthPercentage) -> Size<T>
Returns a Size where with width and height set to the same fit-content(…) value
with the given argument.
Sourceimpl<T> Size<T>where
T: FromLength,
impl<T> Size<T>where
T: FromLength,