pub trait BlockContainerStyle: CoreStyle {
// Provided method
fn text_align(&self) -> TextAlign { ... }
}Expand description
The set of styles required for a Block layout container
Provided Methods
Sourcefn text_align(&self) -> TextAlign
fn text_align(&self) -> TextAlign
Defines which row in the grid the item should start and end at
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<T> BlockContainerStyle for &Twhere
T: BlockContainerStyle,
Available on crate feature block_layout only.
impl<T> BlockContainerStyle for &Twhere
T: BlockContainerStyle,
Available on crate feature
block_layout only.fn text_align(&self) -> TextAlign
Implementors
impl<S> BlockContainerStyle for Style<S>where
S: CheapCloneStr,
Available on crate feature
block_layout only.